@@ -323,9 +323,11 @@ int get_vendor(void){
 
 int get_cputype(int gettype){
   int eax, ebx, ecx, edx;
+/*
   int extend_family, family;
   int extend_model, model;
   int type, stepping;
+*/
   int feature = 0;
 
   cpuid(1, &eax, &ebx, &ecx, &edx);
@@ -428,7 +430,8 @@ int get_cacheinfo(int type, cache_info_t *cacheinfo){
   cpuid(0, &cpuid_level, &ebx, &ecx, &edx);
 
   if (cpuid_level > 1) {
-    int numcalls =0 ;
+    int numcalls;
+    
     cpuid(2, &eax, &ebx, &ecx, &edx);
     numcalls = BITMASK(eax, 0, 0xff); //FIXME some systems may require repeated calls to read all entries
     info[ 0] = BITMASK(eax,  8, 0xff);
@@ -1476,6 +1479,8 @@ int get_cpuname(void){
           else
 	    return CPUTYPE_NEHALEM;
 	case 15: // Sapphire Rapids
+	  if(support_amx_bf16())
+	    return CPUTYPE_SAPPHIRERAPIDS;
 	  if(support_avx512_bf16())
             return CPUTYPE_COOPERLAKE;	
           if(support_avx512())
@@ -1492,6 +1497,10 @@ int get_cpuname(void){
         switch (model) {
         case 7: // Alder Lake desktop
         case 10: // Alder Lake mobile
+	  if(support_avx512_bf16())
+            return CPUTYPE_COOPERLAKE;	
+          if(support_avx512())
+            return CPUTYPE_SKYLAKEX;
           if(support_avx2())
             return CPUTYPE_HASWELL;
           if(support_avx())
@@ -1537,6 +1546,20 @@ int get_cpuname(void){
 	    return CPUTYPE_NEHALEM;
         }
         break;
+      case 11: //family 6 exmodel 11
+        switch (model) {
+          case 7: // Raptor Lake
+          case 10:
+          case 15:
+	  case 14: // Alder Lake N
+            if(support_avx2())
+              return CPUTYPE_HASWELL;
+	    if(support_avx())
+	      return CPUTYPE_SANDYBRIDGE;
+            else
+	      return CPUTYPE_NEHALEM;
+        }
+        break;
       }
       break;    
     case 0x7:
@@ -1637,7 +1660,6 @@ int get_cpuname(void){
 	  else
 	    return CPUTYPE_BARCELONA;
         }
-	break;	      
       case 10: // Zen3		      
 	if(support_avx())
 #ifndef NO_AVX2
@@ -1701,8 +1723,18 @@ int get_cpuname(void){
       if (model == 0xf && stepping < 0xe)
         return CPUTYPE_NANO;
       return CPUTYPE_NEHALEM;
+    case 0x7:
+      switch (exmodel) {
+      case 5:
+        if (support_avx2())
+          return CPUTYPE_ZEN;
+        else
+          return CPUTYPE_DUNNINGTON;
+      default:
+        return CPUTYPE_NEHALEM;
+      }
     default:
-      if (family >= 0x7)
+      if (family >= 0x8)
         return CPUTYPE_NEHALEM;
       else
         return CPUTYPE_VIAC3;
@@ -1710,7 +1742,20 @@ int get_cpuname(void){
   }
 
   if (vendor == VENDOR_ZHAOXIN){
-    return CPUTYPE_NEHALEM;
+    switch (family) {
+      case 0x7:
+        switch (exmodel) {
+        case 5:
+          if (support_avx2())
+            return CPUTYPE_ZEN;
+          else
+            return CPUTYPE_DUNNINGTON;
+        default:
+          return CPUTYPE_NEHALEM;
+        }
+      default:
+        return CPUTYPE_NEHALEM;
+    }
   }
 
   if (vendor == VENDOR_RISE){
@@ -1803,7 +1848,8 @@ static char *cpuname[] = {
   "ZEN",
   "SKYLAKEX",
   "DHYANA",
-  "COOPERLAKE"
+  "COOPERLAKE",
+  "SAPPHIRERAPIDS",
 };
 
 static char *lowercpuname[] = {
@@ -1860,7 +1906,8 @@ static char *lowercpuname[] = {
   "zen",
   "skylakex",
   "dhyana",
-  "cooperlake"
+  "cooperlake",
+  "sapphirerapids",
 };
 
 static char *corename[] = {
@@ -1894,7 +1941,8 @@ static char *corename[] = {
   "ZEN",
   "SKYLAKEX",
   "DHYANA",
-  "COOPERLAKE"
+  "COOPERLAKE",
+  "SAPPHIRERAPIDS",
 };
 
 static char *corename_lower[] = {
@@ -1928,7 +1976,8 @@ static char *corename_lower[] = {
   "zen",
   "skylakex",
   "dhyana",
-  "cooperlake"
+  "cooperlake",
+  "sapphirerapids",
 };
 
 
@@ -2193,7 +2242,6 @@ int get_coretype(void){
 	  else
 	    return CORE_NEHALEM;
 #endif	
-        break;    	
 
       case 7:
         if (model == 10) 
@@ -2235,16 +2283,18 @@ int get_coretype(void){
             return CORE_NEHALEM;
 	}
         if (model == 15) { // Sapphire Rapids
+	  if(support_amx_bf16())
+	    return CORE_SAPPHIRERAPIDS;
 	  if(support_avx512_bf16())
-            return CPUTYPE_COOPERLAKE;	
+            return CORE_COOPERLAKE;	
           if(support_avx512())
-            return CPUTYPE_SKYLAKEX;
+            return CORE_SKYLAKEX;
           if(support_avx2())
-            return CPUTYPE_HASWELL;
+            return CORE_HASWELL;
           if(support_avx())
-	    return CPUTYPE_SANDYBRIDGE;
+	    return CORE_SANDYBRIDGE;
 	  else
-	  return CPUTYPE_NEHALEM;	
+	  return CORE_NEHALEM;
         }
       break;
 
@@ -2306,6 +2356,21 @@ int get_coretype(void){
 	  return CORE_NEHALEM;
         }
 
+      case 11:
+	switch (model) {
+	  case 7: // Raptor Lake
+          case 10:
+          case 15:
+	  case 14: // Alder Lake N	  
+#ifndef NO_AVX2
+	  if(support_avx2())
+            return CORE_HASWELL;
+#endif
+	  if(support_avx())
+	    return CORE_SANDYBRIDGE;
+	  else
+	  return CORE_NEHALEM;
+	}
       case 15:
 	if (model <= 0x2) return CORE_NORTHWOOD;
 	else return CORE_PRESCOTT;
@@ -2411,8 +2476,18 @@ int get_coretype(void){
       if (model == 0xf && stepping < 0xe)
         return CORE_NANO;
       return CORE_NEHALEM;
+    case 0x7:
+      switch (exmodel) {
+      case 5:
+        if (support_avx2())
+          return CORE_ZEN;
+        else
+          return CORE_DUNNINGTON;
+      default:
+        return CORE_NEHALEM;
+      }
     default:
-      if (family >= 0x7)
+      if (family >= 0x8)
         return CORE_NEHALEM;
       else
         return CORE_VIAC3;
@@ -2420,7 +2495,20 @@ int get_coretype(void){
   }
 
   if (vendor == VENDOR_ZHAOXIN) {
-     return CORE_NEHALEM;
+    switch (family) {
+      case 0x7:
+        switch (exmodel) {
+        case 5:
+          if (support_avx2())
+            return CORE_ZEN;
+          else
+            return CORE_DUNNINGTON;
+        default:
+          return CORE_NEHALEM;
+        }
+      default:
+        return CORE_NEHALEM;
+    }
   }
 
   return CORE_UNKNOWN;
@@ -2582,4 +2670,4 @@ void get_sse(void){
   if (features & HAVE_FMA3 )    printf("HAVE_FMA3=1\n");
 
 }
-//}
\ No newline at end of file
+//}
